# -*- encoding: utf-8 -*-

from openerp import models, api, fields
from pytz import timezone
from openerp.tools import DEFAULT_SERVER_DATETIME_FORMAT, DEFAULT_SERVER_DATE_FORMAT
from datetime import datetime,timedelta

DATE_FORMAT = '%Y-%m-%d'

class SaleOrder(models.Model):
    _inherit = 'sale.order'
    _name = 'sale.order'

    invoice_number = fields.Char('Numero de Factura')
    contado = fields.Boolean('Contado')
    credito = fields.Boolean('Crédito')

    _defaults = {
        'contado': True
    }

    @api.one
    @api.onchange('credito')
    def cambiar_estado_credito(self):
        self.contado = not self.credito

    @api.one
    @api.onchange('contado')
    def cambiar_estado_contado(self):
        self.credito = not self.contado

    ''' Timezone '''
    def get_timezone(self):
        return timezone(self._context.get('tz') or self.env.user.tz)

    def _convert_str_to_datetime(self, date):
        return datetime.strptime(date,DEFAULT_SERVER_DATETIME_FORMAT)

    @api.multi
    def order_process_now(self):
        """
        Confirms order and creates and validates invoice, confirms pickings.
        """
        for sale in self:
            sale.action_button_confirm()
            inv_id = sale.action_invoice_create()
            if inv_id:
                inv = self.env['account.invoice'].browse(inv_id)
                date = self._convert_str_to_datetime(sale.date_order)
                date = date.strftime(DATE_FORMAT)
                inv.write({
                    'date_invoice':date,
                    'supplier_invoice_number':self.invoice_number,
                    'contado':self.contado,
                    'credito':self.credito
                })
                self.update_state()
                inv.signal_workflow('invoice_open')
            for picking in sale.picking_ids:
                picking.force_assign()
                picking.action_done()

    @api.multi
    def update_state(self):
        for order in self:
            order.write({'state': 'done'})
        return True

class account_invoice(models.Model):
    _inherit = 'account.invoice'
    _name = 'account.invoice'

    contado = fields.Boolean('Contado')
    credito = fields.Boolean('Crédito')

    _defaults = {
        'contado': True
    }

    @api.one
    @api.onchange('credito')
    def cambiar_estado_credito(self):
        self.contado = not self.credito

    @api.one
    @api.onchange('contado')
    def cambiar_estado_contado(self):
        self.credito = not self.contado
